@@ -1,6 +1,3 @@
-import json
-import urllib.request
-
 from django.apps import apps
 from django.core import signing
 from django.http import JsonResponse, Http404
@@ -58,7 +55,9 @@ def subscribe(request):
             else:
                 client_ip = request.META.get('REMOTE_ADDR')
 
-            if email := form.cleaned_data['email']:
+            email = form.cleaned_data['email']
+
+            if email:
                 user = request.user
                 user.email = email
                 user.save()
@@ -104,17 +103,7 @@ def check_subscription(request):
         return JsonResponse({"is_active": obj.is_active})
 
     except Subscription.DoesNotExist:
-        # TODO: remove this shit code
-        url = 'https://tetris-puzzle.com/api/subscription/check/'
-        data = 'subscription_id=%s' % form.cleaned_data['subscription_id']
-
-        with urllib.request.urlopen(url, data=data.encode()) as resp:
-            if resp.status == 404:
-                raise Http404
-
-            data = json.loads(resp.read().decode('utf-8'))
-
-            return JsonResponse(data, status=resp.status)
+        raise Http404
 
     return JsonResponse({"status": "error", "error": "Something went wrong"}, status=400)
 
@@ -144,17 +133,7 @@ def cancel_subscription(request):
             return JsonResponse({"status": "ok"})
 
     except Subscription.DoesNotExist:
-        # TODO: remove this shit code
-        url = 'https://tetris-puzzle.com/api/subscription/cancel/'
-        data = 'subscription_id=%s' % form.cleaned_data['subscription_id']
-
-        with urllib.request.urlopen(url, data=data.encode()) as resp:
-            if resp.status == 404:
-                raise Http404
-
-            data = json.loads(resp.read().decode('utf-8'))
-
-            return JsonResponse(data, status=resp.status)
+        raise Http404
 
     return JsonResponse({"status": "error", "error": "Something went wrong"}, status=400)
 
